using System;
using System.Collections.Generic;
using System.Linq;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using Avalonia.Controls;
using Avalonia.Interactivity;
using MsBox.Avalonia.Enums;
using MsBox.Avalonia;
using task01.Context;

namespace task01;

public partial class EditWindow : Window
{
    private Employee _employee;
    private List<Department> _departments;
    private List<Profession> _professions;

    public EditWindow(Employee employee, List<Department> departments, List<Profession> professions)
    {
        InitializeComponent();
        this._employee = employee;
        this._departments = departments;
        this._professions = professions;

        LoadData();
    }

    private void LoadData()
    {
        NameTextBox.Text = _employee.Name;
        SurnameTextBox.Text = _employee.Surname;
        PatronymicTextBox.Text = _employee.Patronymic;
        PhoneTextBox.Text = _employee.Phone;
        BirthdayDatePicker.SelectedDate = _employee.Birthday.HasValue ? new DateTimeOffset(_employee.Birthday.Value.ToDateTime(TimeOnly.MinValue)) : (DateTimeOffset?)null;
        DepartmentComboBox.ItemsSource = _departments;
        DepartmentComboBox.SelectedItem = _departments.FirstOrDefault(d => d.Id == _employee.Departmentid);
        ProfessionComboBox.ItemsSource = _professions;
        ProfessionComboBox.SelectedItem = _professions.FirstOrDefault(p => p.Id == _employee.Proffesionid);
        EmailTextBox.Text = _employee.Email;
        OfficeTextBox.Text = _employee.Office.Title;
    }

    private void BackButton_Click(object sender, RoutedEventArgs e)
    {
        var showWindow = new ShowWindow(_employee, _departments, _professions);
        showWindow.Show();
        Close();
    }

    private async void SaveButton_Click(object sender, RoutedEventArgs e)
    {
        var errors = ValidateInput();
        if (errors.Any())
        {
            await ShowError(string.Join(Environment.NewLine, errors));
            return;
        }

        _employee.Name = NameTextBox.Text;
        _employee.Phone = PhoneTextBox.Text;
        if (BirthdayDatePicker.SelectedDate.HasValue)
        {
            _employee.Birthday = DateOnly.FromDateTime(BirthdayDatePicker.SelectedDate.Value.DateTime);
        }
        else
        {
            _employee.Birthday = null;
        }

        _employee.Departmentid = (DepartmentComboBox.SelectedItem as Department).Id;
        _employee.Proffesionid = (ProfessionComboBox.SelectedItem as Profession).Id;
        _employee.Email = EmailTextBox.Text;
        _employee.Office.Title = OfficeTextBox.Text;

        using var context = new User11Context();
        context.Employees.Update(_employee);
        context.SaveChanges();

        var mainWindow = new MainWindow();
        mainWindow.Show();
        Close();
    }

    private void DeleteButton_Click(object sender, RoutedEventArgs e)
    {
        using var context = new User11Context();

        context.Employees.Remove(_employee);
        context.SaveChanges();

        var mainWindow = new MainWindow();
        mainWindow.Show();
        Close();
       
    }

    private List<string> ValidateInput()
    {
        var errors = new List<string>();

        if (string.IsNullOrWhiteSpace(NameTextBox.Text))
        {
            errors.Add("   .");
        }

        if (string.IsNullOrWhiteSpace(PhoneTextBox.Text) || !Regex.IsMatch(PhoneTextBox.Text, @"^[+\d()# -]{1,20}$"))
        {
            errors.Add("        \"+(), -, #\" ( 20 ).");
        }

        if (!BirthdayDatePicker.SelectedDate.HasValue)
        {
            errors.Add("    .");
        }

        if (DepartmentComboBox.SelectedItem == null)
        {
            errors.Add("    .");
        }

        if (ProfessionComboBox.SelectedItem == null)
        {
            errors.Add("   .");
        }

        if (string.IsNullOrWhiteSpace(EmailTextBox.Text) || !Regex.IsMatch(EmailTextBox.Text, @"^[^@\s]+@[^@\s]+\.[^@\s]+$"))
        {
            errors.Add("          x@x.x.");
        }

        if (string.IsNullOrWhiteSpace(OfficeTextBox.Text) || OfficeTextBox.Text.Length > 10)
        {
            errors.Add("    ( 10 ).");
        }

        return errors;
    }

    private async Task ShowError(string message)
    {
        var box = MessageBoxManager
            .GetMessageBoxStandard("", message, ButtonEnum.Ok);
        await box.ShowAsync();
    }
}